@@ -39,6 +39,8 @@ class OEBuild(Base):
     build_dir: str
     envsetup: str = None
     targets: List[str] = None
+    extraconfigs: List[str] = None
+    extraconfigs_cmd: str = ""
     distro: str = None
     build_only: bool = False
     sync_only: bool = False
@@ -241,6 +243,8 @@ class OEBuild(Base):
             validate_local_conf(oebuild_data["local_conf"])
         if oebuild_data.get("bblayers_conf"):
             validate_bblayers_conf(oebuild_data["bblayers_conf"])
+        if oebuild_data.get("extraconfigs"):
+            validate_extraconfigs(oebuild_data["extraconfigs"])
 
         if oebuild_data.get("sstate_dir"):
             check_instance(
@@ -328,6 +332,13 @@ class OEBuild(Base):
             ) as bblayers_conf_file:
                 for line in self.bblayers_conf:
                     bblayers_conf_file.write(f"{line}\n")
+
+        if self.extraconfigs:
+            copies = []
+            for extra in self.extraconfigs:
+                copies.append(f"cp -a {extra} conf/")
+            self.extraconfigs_cmd += "&& " + " && ".join(copies)
+
         return
 
     def do_build(self):
@@ -337,7 +348,7 @@ class OEBuild(Base):
         cmd = [
             "bash",
             "-c",
-            f"rm -f {self.build_dir}/conf/bblayers.conf && rm -f {self.build_dir}/conf/local.conf && source {self.envsetup} {self.build_dir} && cat ../extra_local.conf >> conf/local.conf && cat ../bblayers.conf >> conf/bblayers.conf || true && echo 'Dumping local.conf..' && cat conf/local.conf && bitbake -e > bitbake-environment",
+            f"rm -f {self.build_dir}/conf/bblayers.conf && rm -f {self.build_dir}/conf/local.conf && source {self.envsetup} {self.build_dir} {self.extraconfigs_cmd} && cat ../extra_local.conf >> conf/local.conf && cat ../bblayers.conf >> conf/bblayers.conf || true && echo 'Dumping local.conf..' && cat conf/local.conf && bitbake -e > bitbake-environment",
         ]
         if self._runtime.run_cmd(cmd, offline=False):
             self.result = "pass"
